==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderMemberItem.java <==
package global.hh.openapi.sdk.api.bean.proc;


/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderMemberItem {

    /**
     * 收货人
     */
    private String remark;

    /**
     * 收货人联系电话
     */
    private String num;

    /**
     * 详细地址
     */
    private String cmaterialCode;

    /**
     * 物料编码
     */
    private String receiveAddress;

    /**
     * 数量
     */
    private String receivePhone;

    /**
     * 备注
     */
    private String receiveMan;

    public ProcCreateCmaterialOrderMemberItem(){
    }

    public ProcCreateCmaterialOrderMemberItem(String remark,String num,String cmaterialCode,String receiveAddress,String receivePhone,String receiveMan){
        this.remark=remark;
        this.num=num;
        this.cmaterialCode=cmaterialCode;
        this.receiveAddress=receiveAddress;
        this.receivePhone=receivePhone;
        this.receiveMan=receiveMan;
    }

    private String getRemark() {
        return remark;
    }

    private void setRemark(String remark) {
        this.remark = remark;
    }
    private String getNum() {
        return num;
    }

    private void setNum(String num) {
        this.num = num;
    }
    private String getCmaterialCode() {
        return cmaterialCode;
    }

    private void setCmaterialCode(String cmaterialCode) {
        this.cmaterialCode = cmaterialCode;
    }
    private String getReceiveAddress() {
        return receiveAddress;
    }

    private void setReceiveAddress(String receiveAddress) {
        this.receiveAddress = receiveAddress;
    }
    private String getReceivePhone() {
        return receivePhone;
    }

    private void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }
    private String getReceiveMan() {
        return receiveMan;
    }

    private void setReceiveMan(String receiveMan) {
        this.receiveMan = receiveMan;
    }
}

==> biostime-openapi-sdk-1.5.8.8-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/proc/ProcCreateCmaterialOrderMemberItem.java <==
package global.hh.openapi.sdk.api.bean.proc;


/**
 * @description: 分销平台外部物料订单创建接口
 * @author: 777771
 * @date: 2023-18-27 10:18:35
 */
public class ProcCreateCmaterialOrderMemberItem {

    /**
     * 收货人
     */
    private String remark;

    /**
     * 收货人联系电话
     */
    private String num;

    /**
     * 详细地址
     */
    private String cmaterialCode;

    /**
     * 物料编码
     */
    private String receiveAddress;

    /**
     * 数量
     */
    private String receivePhone;

    /**
     * 备注
     */
    private String receiveMan;

    public ProcCreateCmaterialOrderMemberItem(){
    }

    public ProcCreateCmaterialOrderMemberItem(String remark,String num,String cmaterialCode,String receiveAddress,String receivePhone,String receiveMan){
        this.remark=remark;
        this.num=num;
        this.cmaterialCode=cmaterialCode;
        this.receiveAddress=receiveAddress;
        this.receivePhone=receivePhone;
        this.receiveMan=receiveMan;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getNum() {
        return num;
    }

    public void setNum(String num) {
        this.num = num;
    }
    public String getCmaterialCode() {
        return cmaterialCode;
    }

    public void setCmaterialCode(String cmaterialCode) {
        this.cmaterialCode = cmaterialCode;
    }
    public String getReceiveAddress() {
        return receiveAddress;
    }

    public void setReceiveAddress(String receiveAddress) {
        this.receiveAddress = receiveAddress;
    }
    public String getReceivePhone() {
        return receivePhone;
    }

    public void setReceivePhone(String receivePhone) {
        this.receivePhone = receivePhone;
    }
    public String getReceiveMan() {
        return receiveMan;
    }

    public void setReceiveMan(String receiveMan) {
        this.receiveMan = receiveMan;
    }
}
